struct Module {
name: &'static str,
body_items: Vec<Item>,
use_items: Vec<Item>,
}Fields
name: &'static strbody_items: Vec<Item>All items except use items.
use_items: Vec<Item>Use items are kept separately as they help when the selection is inside an impl block, we can directly take these items and keep them outside generated impl block inside generated module.
Implementations
Sourceimpl Module
impl Module
fn get_usages_and_record_fields( &self, ctx: &AssistContext<'_, '_>, replace_range: TextRange, ) -> (FxHashMap<FileId, Vec<(TextRange, String)>>, Vec<SyntaxNode>, FxHashMap<TextSize, Use>)
fn expand_and_group_usages_file_wise( &self, ctx: &AssistContext<'_, '_>, replace_range: TextRange, node_def: Definition, refs_in_files: &mut FxHashMap<FileId, Vec<(TextRange, String)>>, use_stmts_to_be_inserted: &mut FxHashMap<TextSize, Use>, )
fn change_visibility(&mut self, record_fields: Vec<SyntaxNode>)
fn resolve_imports( &mut self, module: Option<Module>, ctx: &AssistContext<'_, '_>, ) -> Vec<TextRange>
fn process_def_in_sel( &mut self, def: Definition, use_node: &SyntaxNode, curr_parent_module: &Option<Module>, ctx: &AssistContext<'_, '_>, ) -> Option<TextRange>
fn process_use_stmt_for_import_resolve( &self, use_stmt: Option<Use>, node_syntax: &SyntaxNode, ) -> Option<(Vec<Path>, Option<TextRange>)>